Documentation
¶
Index ¶
- type CNIConfiguration
- func (*CNIConfiguration) Descriptor() ([]byte, []int)
- func (m *CNIConfiguration) GetArgs() []*CNIConfiguration_CNIArg
- func (m *CNIConfiguration) GetBinPath() []string
- func (m *CNIConfiguration) GetCacheDir() string
- func (m *CNIConfiguration) GetConfDir() string
- func (m *CNIConfiguration) GetInterfaceName() string
- func (m *CNIConfiguration) GetNetworkName() string
- func (*CNIConfiguration) ProtoMessage()
- func (m *CNIConfiguration) Reset()
- func (m *CNIConfiguration) String() string
- func (m *CNIConfiguration) XXX_DiscardUnknown()
- func (m *CNIConfiguration) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *CNIConfiguration) XXX_Merge(src proto.Message)
- func (m *CNIConfiguration) XXX_Size() int
- func (m *CNIConfiguration) XXX_Unmarshal(b []byte) error
- type CNIConfiguration_CNIArg
- func (*CNIConfiguration_CNIArg) Descriptor() ([]byte, []int)
- func (m *CNIConfiguration_CNIArg) GetKey() string
- func (m *CNIConfiguration_CNIArg) GetValue() string
- func (*CNIConfiguration_CNIArg) ProtoMessage()
- func (m *CNIConfiguration_CNIArg) Reset()
- func (m *CNIConfiguration_CNIArg) String() string
- func (m *CNIConfiguration_CNIArg) XXX_DiscardUnknown()
- func (m *CNIConfiguration_CNIArg) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *CNIConfiguration_CNIArg) XXX_Merge(src proto.Message)
- func (m *CNIConfiguration_CNIArg) XXX_Size() int
- func (m *CNIConfiguration_CNIArg) XXX_Unmarshal(b []byte) error
- type CreateVMRequest
- func (*CreateVMRequest) Descriptor() ([]byte, []int)
- func (m *CreateVMRequest) GetContainerCount() int32
- func (m *CreateVMRequest) GetDriveMounts() []*FirecrackerDriveMount
- func (m *CreateVMRequest) GetExitAfterAllTasksDeleted() bool
- func (m *CreateVMRequest) GetJailerConfig() *JailerConfig
- func (m *CreateVMRequest) GetKernelArgs() string
- func (m *CreateVMRequest) GetKernelImagePath() string
- func (m *CreateVMRequest) GetMachineCfg() *FirecrackerMachineConfiguration
- func (m *CreateVMRequest) GetNetworkInterfaces() []*FirecrackerNetworkInterface
- func (m *CreateVMRequest) GetRootDrive() *FirecrackerRootDrive
- func (m *CreateVMRequest) GetVMID() string
- func (*CreateVMRequest) ProtoMessage()
- func (m *CreateVMRequest) Reset()
- func (m *CreateVMRequest) String() string
- func (m *CreateVMRequest) XXX_DiscardUnknown()
- func (m *CreateVMRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *CreateVMRequest) XXX_Merge(src proto.Message)
- func (m *CreateVMRequest) XXX_Size() int
- func (m *CreateVMRequest) XXX_Unmarshal(b []byte) error
- type CreateVMResponse
- func (*CreateVMResponse) Descriptor() ([]byte, []int)
- func (m *CreateVMResponse) GetCgroupPath() string
- func (m *CreateVMResponse) GetLogFifoPath() string
- func (m *CreateVMResponse) GetMetricsFifoPath() string
- func (m *CreateVMResponse) GetSocketPath() string
- func (m *CreateVMResponse) GetVMID() string
- func (*CreateVMResponse) ProtoMessage()
- func (m *CreateVMResponse) Reset()
- func (m *CreateVMResponse) String() string
- func (m *CreateVMResponse) XXX_DiscardUnknown()
- func (m *CreateVMResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *CreateVMResponse) XXX_Merge(src proto.Message)
- func (m *CreateVMResponse) XXX_Size() int
- func (m *CreateVMResponse) XXX_Unmarshal(b []byte) error
- type ExtraData
- func (*ExtraData) Descriptor() ([]byte, []int)
- func (m *ExtraData) GetJsonSpec() []byte
- func (m *ExtraData) GetRuncOptions() *types.Any
- func (m *ExtraData) GetStderrPort() uint32
- func (m *ExtraData) GetStdinPort() uint32
- func (m *ExtraData) GetStdoutPort() uint32
- func (*ExtraData) ProtoMessage()
- func (m *ExtraData) Reset()
- func (m *ExtraData) String() string
- func (m *ExtraData) XXX_DiscardUnknown()
- func (m *ExtraData) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ExtraData) XXX_Merge(src proto.Message)
- func (m *ExtraData) XXX_Size() int
- func (m *ExtraData) XXX_Unmarshal(b []byte) error
- type FirecrackerDriveMount
- func (*FirecrackerDriveMount) Descriptor() ([]byte, []int)
- func (m *FirecrackerDriveMount) GetFilesystemType() string
- func (m *FirecrackerDriveMount) GetHostPath() string
- func (m *FirecrackerDriveMount) GetIsWritable() bool
- func (m *FirecrackerDriveMount) GetOptions() []string
- func (m *FirecrackerDriveMount) GetRateLimiter() *FirecrackerRateLimiter
- func (m *FirecrackerDriveMount) GetVMPath() string
- func (*FirecrackerDriveMount) ProtoMessage()
- func (m *FirecrackerDriveMount) Reset()
- func (m *FirecrackerDriveMount) String() string
- func (m *FirecrackerDriveMount) XXX_DiscardUnknown()
- func (m *FirecrackerDriveMount) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *FirecrackerDriveMount) XXX_Merge(src proto.Message)
- func (m *FirecrackerDriveMount) XXX_Size() int
- func (m *FirecrackerDriveMount) XXX_Unmarshal(b []byte) error
- type FirecrackerMachineConfiguration
- func (*FirecrackerMachineConfiguration) Descriptor() ([]byte, []int)
- func (m *FirecrackerMachineConfiguration) GetCPUTemplate() string
- func (m *FirecrackerMachineConfiguration) GetHtEnabled() bool
- func (m *FirecrackerMachineConfiguration) GetMemSizeMib() uint32
- func (m *FirecrackerMachineConfiguration) GetVcpuCount() uint32
- func (*FirecrackerMachineConfiguration) ProtoMessage()
- func (m *FirecrackerMachineConfiguration) Reset()
- func (m *FirecrackerMachineConfiguration) String() string
- func (m *FirecrackerMachineConfiguration) XXX_DiscardUnknown()
- func (m *FirecrackerMachineConfiguration) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *FirecrackerMachineConfiguration) XXX_Merge(src proto.Message)
- func (m *FirecrackerMachineConfiguration) XXX_Size() int
- func (m *FirecrackerMachineConfiguration) XXX_Unmarshal(b []byte) error
- type FirecrackerNetworkInterface
- func (*FirecrackerNetworkInterface) Descriptor() ([]byte, []int)
- func (m *FirecrackerNetworkInterface) GetAllowMMDS() bool
- func (m *FirecrackerNetworkInterface) GetCNIConfig() *CNIConfiguration
- func (m *FirecrackerNetworkInterface) GetInRateLimiter() *FirecrackerRateLimiter
- func (m *FirecrackerNetworkInterface) GetOutRateLimiter() *FirecrackerRateLimiter
- func (m *FirecrackerNetworkInterface) GetStaticConfig() *StaticNetworkConfiguration
- func (*FirecrackerNetworkInterface) ProtoMessage()
- func (m *FirecrackerNetworkInterface) Reset()
- func (m *FirecrackerNetworkInterface) String() string
- func (m *FirecrackerNetworkInterface) XXX_DiscardUnknown()
- func (m *FirecrackerNetworkInterface) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *FirecrackerNetworkInterface) XXX_Merge(src proto.Message)
- func (m *FirecrackerNetworkInterface) XXX_Size() int
- func (m *FirecrackerNetworkInterface) XXX_Unmarshal(b []byte) error
- type FirecrackerRateLimiter
- func (*FirecrackerRateLimiter) Descriptor() ([]byte, []int)
- func (m *FirecrackerRateLimiter) GetBandwidth() *FirecrackerTokenBucket
- func (m *FirecrackerRateLimiter) GetOps() *FirecrackerTokenBucket
- func (*FirecrackerRateLimiter) ProtoMessage()
- func (m *FirecrackerRateLimiter) Reset()
- func (m *FirecrackerRateLimiter) String() string
- func (m *FirecrackerRateLimiter) XXX_DiscardUnknown()
- func (m *FirecrackerRateLimiter) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *FirecrackerRateLimiter) XXX_Merge(src proto.Message)
- func (m *FirecrackerRateLimiter) XXX_Size() int
- func (m *FirecrackerRateLimiter) XXX_Unmarshal(b []byte) error
- type FirecrackerRootDrive
- func (*FirecrackerRootDrive) Descriptor() ([]byte, []int)
- func (m *FirecrackerRootDrive) GetHostPath() string
- func (m *FirecrackerRootDrive) GetIsWritable() bool
- func (m *FirecrackerRootDrive) GetPartuuid() string
- func (m *FirecrackerRootDrive) GetRateLimiter() *FirecrackerRateLimiter
- func (*FirecrackerRootDrive) ProtoMessage()
- func (m *FirecrackerRootDrive) Reset()
- func (m *FirecrackerRootDrive) String() string
- func (m *FirecrackerRootDrive) XXX_DiscardUnknown()
- func (m *FirecrackerRootDrive) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *FirecrackerRootDrive) XXX_Merge(src proto.Message)
- func (m *FirecrackerRootDrive) XXX_Size() int
- func (m *FirecrackerRootDrive) XXX_Unmarshal(b []byte) error
- type FirecrackerTokenBucket
- func (*FirecrackerTokenBucket) Descriptor() ([]byte, []int)
- func (m *FirecrackerTokenBucket) GetCapacity() int64
- func (m *FirecrackerTokenBucket) GetOneTimeBurst() int64
- func (m *FirecrackerTokenBucket) GetRefillTime() int64
- func (*FirecrackerTokenBucket) ProtoMessage()
- func (m *FirecrackerTokenBucket) Reset()
- func (m *FirecrackerTokenBucket) String() string
- func (m *FirecrackerTokenBucket) XXX_DiscardUnknown()
- func (m *FirecrackerTokenBucket) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *FirecrackerTokenBucket) XXX_Merge(src proto.Message)
- func (m *FirecrackerTokenBucket) XXX_Size() int
- func (m *FirecrackerTokenBucket) XXX_Unmarshal(b []byte) error
- type GetVMInfoRequest
- func (*GetVMInfoRequest) Descriptor() ([]byte, []int)
- func (m *GetVMInfoRequest) GetVMID() string
- func (*GetVMInfoRequest) ProtoMessage()
- func (m *GetVMInfoRequest) Reset()
- func (m *GetVMInfoRequest) String() string
- func (m *GetVMInfoRequest) XXX_DiscardUnknown()
- func (m *GetVMInfoRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetVMInfoRequest) XXX_Merge(src proto.Message)
- func (m *GetVMInfoRequest) XXX_Size() int
- func (m *GetVMInfoRequest) XXX_Unmarshal(b []byte) error
- type GetVMInfoResponse
- func (*GetVMInfoResponse) Descriptor() ([]byte, []int)
- func (m *GetVMInfoResponse) GetCgroupPath() string
- func (m *GetVMInfoResponse) GetLogFifoPath() string
- func (m *GetVMInfoResponse) GetMetricsFifoPath() string
- func (m *GetVMInfoResponse) GetSocketPath() string
- func (m *GetVMInfoResponse) GetVMID() string
- func (*GetVMInfoResponse) ProtoMessage()
- func (m *GetVMInfoResponse) Reset()
- func (m *GetVMInfoResponse) String() string
- func (m *GetVMInfoResponse) XXX_DiscardUnknown()
- func (m *GetVMInfoResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetVMInfoResponse) XXX_Merge(src proto.Message)
- func (m *GetVMInfoResponse) XXX_Size() int
- func (m *GetVMInfoResponse) XXX_Unmarshal(b []byte) error
- type GetVMMetadataRequest
- func (*GetVMMetadataRequest) Descriptor() ([]byte, []int)
- func (m *GetVMMetadataRequest) GetVMID() string
- func (*GetVMMetadataRequest) ProtoMessage()
- func (m *GetVMMetadataRequest) Reset()
- func (m *GetVMMetadataRequest) String() string
- func (m *GetVMMetadataRequest) XXX_DiscardUnknown()
- func (m *GetVMMetadataRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetVMMetadataRequest) XXX_Merge(src proto.Message)
- func (m *GetVMMetadataRequest) XXX_Size() int
- func (m *GetVMMetadataRequest) XXX_Unmarshal(b []byte) error
- type GetVMMetadataResponse
- func (*GetVMMetadataResponse) Descriptor() ([]byte, []int)
- func (m *GetVMMetadataResponse) GetMetadata() string
- func (*GetVMMetadataResponse) ProtoMessage()
- func (m *GetVMMetadataResponse) Reset()
- func (m *GetVMMetadataResponse) String() string
- func (m *GetVMMetadataResponse) XXX_DiscardUnknown()
- func (m *GetVMMetadataResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetVMMetadataResponse) XXX_Merge(src proto.Message)
- func (m *GetVMMetadataResponse) XXX_Size() int
- func (m *GetVMMetadataResponse) XXX_Unmarshal(b []byte) error
- type IPConfiguration
- func (*IPConfiguration) Descriptor() ([]byte, []int)
- func (m *IPConfiguration) GetGatewayAddr() string
- func (m *IPConfiguration) GetNameservers() []string
- func (m *IPConfiguration) GetPrimaryAddr() string
- func (*IPConfiguration) ProtoMessage()
- func (m *IPConfiguration) Reset()
- func (m *IPConfiguration) String() string
- func (m *IPConfiguration) XXX_DiscardUnknown()
- func (m *IPConfiguration) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *IPConfiguration) XXX_Merge(src proto.Message)
- func (m *IPConfiguration) XXX_Size() int
- func (m *IPConfiguration) XXX_Unmarshal(b []byte) error
- type JailerConfig
- func (*JailerConfig) Descriptor() ([]byte, []int)
- func (m *JailerConfig) GetCPUs() string
- func (m *JailerConfig) GetGID() uint32
- func (m *JailerConfig) GetMems() string
- func (m *JailerConfig) GetNetNS() string
- func (m *JailerConfig) GetUID() uint32
- func (*JailerConfig) ProtoMessage()
- func (m *JailerConfig) Reset()
- func (m *JailerConfig) String() string
- func (m *JailerConfig) XXX_DiscardUnknown()
- func (m *JailerConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *JailerConfig) XXX_Merge(src proto.Message)
- func (m *JailerConfig) XXX_Size() int
- func (m *JailerConfig) XXX_Unmarshal(b []byte) error
- type SetVMMetadataRequest
- func (*SetVMMetadataRequest) Descriptor() ([]byte, []int)
- func (m *SetVMMetadataRequest) GetMetadata() string
- func (m *SetVMMetadataRequest) GetVMID() string
- func (*SetVMMetadataRequest) ProtoMessage()
- func (m *SetVMMetadataRequest) Reset()
- func (m *SetVMMetadataRequest) String() string
- func (m *SetVMMetadataRequest) XXX_DiscardUnknown()
- func (m *SetVMMetadataRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *SetVMMetadataRequest) XXX_Merge(src proto.Message)
- func (m *SetVMMetadataRequest) XXX_Size() int
- func (m *SetVMMetadataRequest) XXX_Unmarshal(b []byte) error
- type StaticNetworkConfiguration
- func (*StaticNetworkConfiguration) Descriptor() ([]byte, []int)
- func (m *StaticNetworkConfiguration) GetHostDevName() string
- func (m *StaticNetworkConfiguration) GetIPConfig() *IPConfiguration
- func (m *StaticNetworkConfiguration) GetMacAddress() string
- func (*StaticNetworkConfiguration) ProtoMessage()
- func (m *StaticNetworkConfiguration) Reset()
- func (m *StaticNetworkConfiguration) String() string
- func (m *StaticNetworkConfiguration) XXX_DiscardUnknown()
- func (m *StaticNetworkConfiguration) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *StaticNetworkConfiguration) XXX_Merge(src proto.Message)
- func (m *StaticNetworkConfiguration) XXX_Size() int
- func (m *StaticNetworkConfiguration) XXX_Unmarshal(b []byte) error
- type StopVMRequest
- func (*StopVMRequest) Descriptor() ([]byte, []int)
- func (m *StopVMRequest) GetTimeoutSeconds() uint32
- func (m *StopVMRequest) GetVMID() string
- func (*StopVMRequest) ProtoMessage()
- func (m *StopVMRequest) Reset()
- func (m *StopVMRequest) String() string
- func (m *StopVMRequest) XXX_DiscardUnknown()
- func (m *StopVMRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *StopVMRequest) XXX_Merge(src proto.Message)
- func (m *StopVMRequest) XXX_Size() int
- func (m *StopVMRequest) XXX_Unmarshal(b []byte) error
- type UpdateVMMetadataRequest
- func (*UpdateVMMetadataRequest) Descriptor() ([]byte, []int)
- func (m *UpdateVMMetadataRequest) GetMetadata() string
- func (m *UpdateVMMetadataRequest) GetVMID() string
- func (*UpdateVMMetadataRequest) ProtoMessage()
- func (m *UpdateVMMetadataRequest) Reset()
- func (m *UpdateVMMetadataRequest) String() string
- func (m *UpdateVMMetadataRequest) XXX_DiscardUnknown()
- func (m *UpdateVMMetadataRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *UpdateVMMetadataRequest) XXX_Merge(src proto.Message)
- func (m *UpdateVMMetadataRequest) XXX_Size() int
- func (m *UpdateVMMetadataRequest) XXX_Unmarshal(b []byte) error
- type VMStart
- func (*VMStart) Descriptor() ([]byte, []int)
- func (m *VMStart) GetVMID() string
- func (*VMStart) ProtoMessage()
- func (m *VMStart) Reset()
- func (m *VMStart) String() string
- func (m *VMStart) XXX_DiscardUnknown()
- func (m *VMStart) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *VMStart) XXX_Merge(src proto.Message)
- func (m *VMStart) XXX_Size() int
- func (m *VMStart) XXX_Unmarshal(b []byte) error
- type VMStop
- func (*VMStop) Descriptor() ([]byte, []int)
- func (m *VMStop) GetVMID() string
- func (*VMStop) ProtoMessage()
- func (m *VMStop) Reset()
- func (m *VMStop) String() string
- func (m *VMStop) XXX_DiscardUnknown()
- func (m *VMStop) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *VMStop) XXX_Merge(src proto.Message)
- func (m *VMStop) XXX_Size() int
- func (m *VMStop) XXX_Unmarshal(b []byte) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CNIConfiguration ¶
type CNIConfiguration struct {
// NetworkName is the name of a CNI network (as found in CNI
// configuration files) that will be used to generate the
// network interface.
NetworkName string `protobuf:"bytes,1,opt,name=NetworkName,json=networkName,proto3" json:"NetworkName,omitempty"`
// InterfaceName corresponds to the CNI_IFNAME parameter that will be
// provided to CNI plugins during invocation.
InterfaceName string `protobuf:"bytes,2,opt,name=InterfaceName,json=interfaceName,proto3" json:"InterfaceName,omitempty"`
// BinPath is a list of directories that will be searched when
// looking for CNI plugin binaries. Defaults to just "/opt/cni/bin"
BinPath []string `protobuf:"bytes,3,rep,name=BinPath,json=binPath,proto3" json:"BinPath,omitempty"`
// ConfDir is the directory in which CNI configuration will be sought.
// If not specified, will default to "/etc/cni/conf.d".
ConfDir string `protobuf:"bytes,4,opt,name=ConfDir,json=confDir,proto3" json:"ConfDir,omitempty"`
// CacheDir is the directory in which CNI results will be temporarily
// cached by the runtime. If not specified, it will default to
// "/var/lib/cni"
CacheDir string `protobuf:"bytes,5,opt,name=CacheDir,json=cacheDir,proto3" json:"CacheDir,omitempty"`
// Args corresponds to the CNI_ARGS parameter that will be provided to
// CNI plugins on invocation.
Args []*CNIConfiguration_CNIArg `protobuf:"bytes,6,rep,name=Args,json=args,proto3" json:"Args,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Message to specify CNI configuration that will be used to generate a network interface for a Firecracker VM
func (*CNIConfiguration) Descriptor ¶
func (*CNIConfiguration) Descriptor() ([]byte, []int)
func (*CNIConfiguration) GetArgs ¶
func (m *CNIConfiguration) GetArgs() []*CNIConfiguration_CNIArg
func (*CNIConfiguration) GetBinPath ¶
func (m *CNIConfiguration) GetBinPath() []string
func (*CNIConfiguration) GetCacheDir ¶
func (m *CNIConfiguration) GetCacheDir() string
func (*CNIConfiguration) GetConfDir ¶
func (m *CNIConfiguration) GetConfDir() string
func (*CNIConfiguration) GetInterfaceName ¶
func (m *CNIConfiguration) GetInterfaceName() string
func (*CNIConfiguration) GetNetworkName ¶
func (m *CNIConfiguration) GetNetworkName() string
func (*CNIConfiguration) ProtoMessage ¶
func (*CNIConfiguration) ProtoMessage()
func (*CNIConfiguration) Reset ¶
func (m *CNIConfiguration) Reset()
func (*CNIConfiguration) String ¶
func (m *CNIConfiguration) String() string
func (*CNIConfiguration) XXX_DiscardUnknown ¶
func (m *CNIConfiguration) XXX_DiscardUnknown()
func (*CNIConfiguration) XXX_Marshal ¶
func (m *CNIConfiguration) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*CNIConfiguration) XXX_Merge ¶
func (m *CNIConfiguration) XXX_Merge(src proto.Message)
func (*CNIConfiguration) XXX_Size ¶
func (m *CNIConfiguration) XXX_Size() int
func (*CNIConfiguration) XXX_Unmarshal ¶
func (m *CNIConfiguration) XXX_Unmarshal(b []byte) error
type CNIConfiguration_CNIArg ¶
type CNIConfiguration_CNIArg struct {
Key string `protobuf:"bytes,1,opt,name=Key,json=key,proto3" json:"Key,omitempty"`
Value string `protobuf:"bytes,2,opt,name=Value,json=value,proto3" json:"Value,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*CNIConfiguration_CNIArg) Descriptor ¶
func (*CNIConfiguration_CNIArg) Descriptor() ([]byte, []int)
func (*CNIConfiguration_CNIArg) GetKey ¶
func (m *CNIConfiguration_CNIArg) GetKey() string
func (*CNIConfiguration_CNIArg) GetValue ¶
func (m *CNIConfiguration_CNIArg) GetValue() string
func (*CNIConfiguration_CNIArg) ProtoMessage ¶
func (*CNIConfiguration_CNIArg) ProtoMessage()
func (*CNIConfiguration_CNIArg) Reset ¶
func (m *CNIConfiguration_CNIArg) Reset()
func (*CNIConfiguration_CNIArg) String ¶
func (m *CNIConfiguration_CNIArg) String() string
func (*CNIConfiguration_CNIArg) XXX_DiscardUnknown ¶
func (m *CNIConfiguration_CNIArg) XXX_DiscardUnknown()
func (*CNIConfiguration_CNIArg) XXX_Marshal ¶
func (m *CNIConfiguration_CNIArg) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*CNIConfiguration_CNIArg) XXX_Merge ¶
func (m *CNIConfiguration_CNIArg) XXX_Merge(src proto.Message)
func (*CNIConfiguration_CNIArg) XXX_Size ¶
func (m *CNIConfiguration_CNIArg) XXX_Size() int
func (*CNIConfiguration_CNIArg) XXX_Unmarshal ¶
func (m *CNIConfiguration_CNIArg) XXX_Unmarshal(b []byte) error
type CreateVMRequest ¶
type CreateVMRequest struct {
// VM identifier to assign
VMID string `protobuf:"bytes,1,opt,name=VMID,json=vMID,proto3" json:"VMID,omitempty"`
// Specifies the machine configuration for the VM
MachineCfg *FirecrackerMachineConfiguration `protobuf:"bytes,2,opt,name=MachineCfg,json=machineCfg,proto3" json:"MachineCfg,omitempty"`
// Specifies the file path where the kernel image is located
KernelImagePath string `protobuf:"bytes,3,opt,name=KernelImagePath,json=kernelImagePath,proto3" json:"KernelImagePath,omitempty"`
// Specifies the commandline arguments that should be passed to the kernel
KernelArgs string `protobuf:"bytes,4,opt,name=KernelArgs,json=kernelArgs,proto3" json:"KernelArgs,omitempty"`
// Specifies drive containing the rootfs of the VM
RootDrive *FirecrackerRootDrive `protobuf:"bytes,5,opt,name=RootDrive,json=rootDrive,proto3" json:"RootDrive,omitempty"`
// Specifies additional drives whose contents will be mounted inside the VM on boot.
DriveMounts []*FirecrackerDriveMount `protobuf:"bytes,6,rep,name=DriveMounts,json=driveMounts,proto3" json:"DriveMounts,omitempty"`
// Specifies the networking configuration for a VM
NetworkInterfaces []*FirecrackerNetworkInterface `protobuf:"bytes,7,rep,name=NetworkInterfaces,json=networkInterfaces,proto3" json:"NetworkInterfaces,omitempty"`
// The number of dummy drives to reserve in advance before running FC instance.
ContainerCount int32 `protobuf:"varint,8,opt,name=ContainerCount,json=containerCount,proto3" json:"ContainerCount,omitempty"`
// Whether the VM should exit after all tasks running in it have been deleted.
ExitAfterAllTasksDeleted bool `` /* 132-byte string literal not displayed */
JailerConfig *JailerConfig `protobuf:"bytes,10,opt,name=JailerConfig,json=jailerConfig,proto3" json:"JailerConfig,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
CreateVMRequest specifies creation parameters for a new FC instance
func (*CreateVMRequest) Descriptor ¶
func (*CreateVMRequest) Descriptor() ([]byte, []int)
func (*CreateVMRequest) GetContainerCount ¶
func (m *CreateVMRequest) GetContainerCount() int32
func (*CreateVMRequest) GetDriveMounts ¶
func (m *CreateVMRequest) GetDriveMounts() []*FirecrackerDriveMount
func (*CreateVMRequest) GetExitAfterAllTasksDeleted ¶
func (m *CreateVMRequest) GetExitAfterAllTasksDeleted() bool
func (*CreateVMRequest) GetJailerConfig ¶
func (m *CreateVMRequest) GetJailerConfig() *JailerConfig
func (*CreateVMRequest) GetKernelArgs ¶
func (m *CreateVMRequest) GetKernelArgs() string
func (*CreateVMRequest) GetKernelImagePath ¶
func (m *CreateVMRequest) GetKernelImagePath() string
func (*CreateVMRequest) GetMachineCfg ¶
func (m *CreateVMRequest) GetMachineCfg() *FirecrackerMachineConfiguration
func (*CreateVMRequest) GetNetworkInterfaces ¶
func (m *CreateVMRequest) GetNetworkInterfaces() []*FirecrackerNetworkInterface
func (*CreateVMRequest) GetRootDrive ¶
func (m *CreateVMRequest) GetRootDrive() *FirecrackerRootDrive
func (*CreateVMRequest) GetVMID ¶
func (m *CreateVMRequest) GetVMID() string
func (*CreateVMRequest) ProtoMessage ¶
func (*CreateVMRequest) ProtoMessage()
func (*CreateVMRequest) Reset ¶
func (m *CreateVMRequest) Reset()
func (*CreateVMRequest) String ¶
func (m *CreateVMRequest) String() string
func (*CreateVMRequest) XXX_DiscardUnknown ¶
func (m *CreateVMRequest) XXX_DiscardUnknown()
func (*CreateVMRequest) XXX_Marshal ¶
func (m *CreateVMRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*CreateVMRequest) XXX_Merge ¶
func (m *CreateVMRequest) XXX_Merge(src proto.Message)
func (*CreateVMRequest) XXX_Size ¶
func (m *CreateVMRequest) XXX_Size() int
func (*CreateVMRequest) XXX_Unmarshal ¶
func (m *CreateVMRequest) XXX_Unmarshal(b []byte) error
type CreateVMResponse ¶
type CreateVMResponse struct {
VMID string `protobuf:"bytes,1,opt,name=VMID,json=vMID,proto3" json:"VMID,omitempty"`
SocketPath string `protobuf:"bytes,2,opt,name=SocketPath,json=socketPath,proto3" json:"SocketPath,omitempty"`
LogFifoPath string `protobuf:"bytes,3,opt,name=LogFifoPath,json=logFifoPath,proto3" json:"LogFifoPath,omitempty"`
MetricsFifoPath string `protobuf:"bytes,4,opt,name=MetricsFifoPath,json=metricsFifoPath,proto3" json:"MetricsFifoPath,omitempty"`
CgroupPath string `protobuf:"bytes,5,opt,name=CgroupPath,json=cgroupPath,proto3" json:"CgroupPath,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*CreateVMResponse) Descriptor ¶
func (*CreateVMResponse) Descriptor() ([]byte, []int)
func (*CreateVMResponse) GetCgroupPath ¶
func (m *CreateVMResponse) GetCgroupPath() string
func (*CreateVMResponse) GetLogFifoPath ¶
func (m *CreateVMResponse) GetLogFifoPath() string
func (*CreateVMResponse) GetMetricsFifoPath ¶
func (m *CreateVMResponse) GetMetricsFifoPath() string
func (*CreateVMResponse) GetSocketPath ¶
func (m *CreateVMResponse) GetSocketPath() string
func (*CreateVMResponse) GetVMID ¶
func (m *CreateVMResponse) GetVMID() string
func (*CreateVMResponse) ProtoMessage ¶
func (*CreateVMResponse) ProtoMessage()
func (*CreateVMResponse) Reset ¶
func (m *CreateVMResponse) Reset()
func (*CreateVMResponse) String ¶
func (m *CreateVMResponse) String() string
func (*CreateVMResponse) XXX_DiscardUnknown ¶
func (m *CreateVMResponse) XXX_DiscardUnknown()
func (*CreateVMResponse) XXX_Marshal ¶
func (m *CreateVMResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*CreateVMResponse) XXX_Merge ¶
func (m *CreateVMResponse) XXX_Merge(src proto.Message)
func (*CreateVMResponse) XXX_Size ¶
func (m *CreateVMResponse) XXX_Size() int
func (*CreateVMResponse) XXX_Unmarshal ¶
func (m *CreateVMResponse) XXX_Unmarshal(b []byte) error
type ExtraData ¶
type ExtraData struct {
JsonSpec []byte `protobuf:"bytes,1,opt,name=JsonSpec,json=jsonSpec,proto3" json:"JsonSpec,omitempty"`
RuncOptions *types.Any `protobuf:"bytes,2,opt,name=RuncOptions,json=runcOptions,proto3" json:"RuncOptions,omitempty"`
StdinPort uint32 `protobuf:"varint,3,opt,name=StdinPort,json=stdinPort,proto3" json:"StdinPort,omitempty"`
StdoutPort uint32 `protobuf:"varint,4,opt,name=StdoutPort,json=stdoutPort,proto3" json:"StdoutPort,omitempty"`
StderrPort uint32 `protobuf:"varint,5,opt,name=StderrPort,json=stderrPort,proto3" json:"StderrPort,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Message to store bundle/config.json bytes
func (*ExtraData) Descriptor ¶
func (*ExtraData) GetJsonSpec ¶
func (*ExtraData) GetRuncOptions ¶
func (*ExtraData) GetStderrPort ¶
func (*ExtraData) GetStdinPort ¶
func (*ExtraData) GetStdoutPort ¶
func (*ExtraData) ProtoMessage ¶
func (*ExtraData) ProtoMessage()
func (*ExtraData) XXX_DiscardUnknown ¶
func (m *ExtraData) XXX_DiscardUnknown()
func (*ExtraData) XXX_Marshal ¶
func (*ExtraData) XXX_Unmarshal ¶
type FirecrackerDriveMount ¶
type FirecrackerDriveMount struct {
// (Required) HostPath is the path on the host to the filesystem image or device
// that will be mounted inside the VM.
HostPath string `protobuf:"bytes,1,opt,name=HostPath,json=hostPath,proto3" json:"HostPath,omitempty"`
// (Required) VMPath is the path inside the VM guest at which the filesystem
// image or device will be mounted.
VMPath string `protobuf:"bytes,2,opt,name=VMPath,json=vMPath,proto3" json:"VMPath,omitempty"`
// (Required) FilesystemType is the filesystem type (i.e. ext4, xfs, etc.), as
// used when mounting the filesystem image inside the VM. The VM guest kernel
// is expected to have support for this filesystem.
FilesystemType string `protobuf:"bytes,3,opt,name=FilesystemType,json=filesystemType,proto3" json:"FilesystemType,omitempty"`
// (Optional) Options are fstab-style options that the mount will be performed
// within the VM (i.e. ["rw", "noatime"]). Defaults to none if not specified.
Options []string `protobuf:"bytes,4,rep,name=Options,json=options,proto3" json:"Options,omitempty"`
// (Optional) RateLimiter configuration that will be applied to the
// backing-drive for the VM's rootfs
RateLimiter *FirecrackerRateLimiter `protobuf:"bytes,5,opt,name=RateLimiter,json=rateLimiter,proto3" json:"RateLimiter,omitempty"`
// (Optional) If set to true, IsWritable results in the backing file for the
// drive being opened as read-write by the Firecracker VMM on the host, allowing
// writes to the image from within the guest. Defaults to false, in which case
// the block device in the VM will be read-only.
IsWritable bool `protobuf:"varint,6,opt,name=IsWritable,json=isWritable,proto3" json:"IsWritable,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*FirecrackerDriveMount) Descriptor ¶
func (*FirecrackerDriveMount) Descriptor() ([]byte, []int)
func (*FirecrackerDriveMount) GetFilesystemType ¶
func (m *FirecrackerDriveMount) GetFilesystemType() string
func (*FirecrackerDriveMount) GetHostPath ¶
func (m *FirecrackerDriveMount) GetHostPath() string
func (*FirecrackerDriveMount) GetIsWritable ¶
func (m *FirecrackerDriveMount) GetIsWritable() bool
func (*FirecrackerDriveMount) GetOptions ¶
func (m *FirecrackerDriveMount) GetOptions() []string
func (*FirecrackerDriveMount) GetRateLimiter ¶
func (m *FirecrackerDriveMount) GetRateLimiter() *FirecrackerRateLimiter
func (*FirecrackerDriveMount) GetVMPath ¶
func (m *FirecrackerDriveMount) GetVMPath() string
func (*FirecrackerDriveMount) ProtoMessage ¶
func (*FirecrackerDriveMount) ProtoMessage()
func (*FirecrackerDriveMount) Reset ¶
func (m *FirecrackerDriveMount) Reset()
func (*FirecrackerDriveMount) String ¶
func (m *FirecrackerDriveMount) String() string
func (*FirecrackerDriveMount) XXX_DiscardUnknown ¶
func (m *FirecrackerDriveMount) XXX_DiscardUnknown()
func (*FirecrackerDriveMount) XXX_Marshal ¶
func (m *FirecrackerDriveMount) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*FirecrackerDriveMount) XXX_Merge ¶
func (m *FirecrackerDriveMount) XXX_Merge(src proto.Message)
func (*FirecrackerDriveMount) XXX_Size ¶
func (m *FirecrackerDriveMount) XXX_Size() int
func (*FirecrackerDriveMount) XXX_Unmarshal ¶
func (m *FirecrackerDriveMount) XXX_Unmarshal(b []byte) error
type FirecrackerMachineConfiguration ¶
type FirecrackerMachineConfiguration struct {
CPUTemplate string `protobuf:"bytes,1,opt,name=CPUTemplate,json=cPUTemplate,proto3" json:"CPUTemplate,omitempty"`
HtEnabled bool `protobuf:"varint,2,opt,name=HtEnabled,json=htEnabled,proto3" json:"HtEnabled,omitempty"`
// Specifies the memory size of VM
// This lets us create a Firecracker VM of up to 4096 TiB, which
// for a microVM should be large enough
MemSizeMib uint32 `protobuf:"varint,3,opt,name=MemSizeMib,json=memSizeMib,proto3" json:"MemSizeMib,omitempty"`
VcpuCount uint32 `protobuf:"varint,4,opt,name=VcpuCount,json=vcpuCount,proto3" json:"VcpuCount,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Message to set the machine config for a Firecracker VM
func (*FirecrackerMachineConfiguration) Descriptor ¶
func (*FirecrackerMachineConfiguration) Descriptor() ([]byte, []int)
func (*FirecrackerMachineConfiguration) GetCPUTemplate ¶
func (m *FirecrackerMachineConfiguration) GetCPUTemplate() string
func (*FirecrackerMachineConfiguration) GetHtEnabled ¶
func (m *FirecrackerMachineConfiguration) GetHtEnabled() bool
func (*FirecrackerMachineConfiguration) GetMemSizeMib ¶
func (m *FirecrackerMachineConfiguration) GetMemSizeMib() uint32
func (*FirecrackerMachineConfiguration) GetVcpuCount ¶
func (m *FirecrackerMachineConfiguration) GetVcpuCount() uint32
func (*FirecrackerMachineConfiguration) ProtoMessage ¶
func (*FirecrackerMachineConfiguration) ProtoMessage()
func (*FirecrackerMachineConfiguration) Reset ¶
func (m *FirecrackerMachineConfiguration) Reset()
func (*FirecrackerMachineConfiguration) String ¶
func (m *FirecrackerMachineConfiguration) String() string
func (*FirecrackerMachineConfiguration) XXX_DiscardUnknown ¶
func (m *FirecrackerMachineConfiguration) XXX_DiscardUnknown()
func (*FirecrackerMachineConfiguration) XXX_Marshal ¶
func (m *FirecrackerMachineConfiguration) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*FirecrackerMachineConfiguration) XXX_Merge ¶
func (m *FirecrackerMachineConfiguration) XXX_Merge(src proto.Message)
func (*FirecrackerMachineConfiguration) XXX_Size ¶
func (m *FirecrackerMachineConfiguration) XXX_Size() int
func (*FirecrackerMachineConfiguration) XXX_Unmarshal ¶
func (m *FirecrackerMachineConfiguration) XXX_Unmarshal(b []byte) error
type FirecrackerNetworkInterface ¶
type FirecrackerNetworkInterface struct {
AllowMMDS bool `protobuf:"varint,1,opt,name=AllowMMDS,json=allowMMDS,proto3" json:"AllowMMDS,omitempty"`
InRateLimiter *FirecrackerRateLimiter `protobuf:"bytes,2,opt,name=InRateLimiter,json=inRateLimiter,proto3" json:"InRateLimiter,omitempty"`
OutRateLimiter *FirecrackerRateLimiter `protobuf:"bytes,3,opt,name=OutRateLimiter,json=outRateLimiter,proto3" json:"OutRateLimiter,omitempty"`
// CNIConfiguration specifies CNI configuration that will be used to generate
// a network interface for a Firecracker VM.
CNIConfig *CNIConfiguration `protobuf:"bytes,4,opt,name=CNIConfig,json=cNIConfig,proto3" json:"CNIConfig,omitempty"`
// StaticNetworkConfiguration specifies static configuration parameters for a
// Firecracker VM's network interface
StaticConfig *StaticNetworkConfiguration `protobuf:"bytes,5,opt,name=StaticConfig,json=staticConfig,proto3" json:"StaticConfig,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Message to specify network config for a Firecracker VM
func (*FirecrackerNetworkInterface) Descriptor ¶
func (*FirecrackerNetworkInterface) Descriptor() ([]byte, []int)
func (*FirecrackerNetworkInterface) GetAllowMMDS ¶
func (m *FirecrackerNetworkInterface) GetAllowMMDS() bool
func (*FirecrackerNetworkInterface) GetCNIConfig ¶
func (m *FirecrackerNetworkInterface) GetCNIConfig() *CNIConfiguration
func (*FirecrackerNetworkInterface) GetInRateLimiter ¶
func (m *FirecrackerNetworkInterface) GetInRateLimiter() *FirecrackerRateLimiter
func (*FirecrackerNetworkInterface) GetOutRateLimiter ¶
func (m *FirecrackerNetworkInterface) GetOutRateLimiter() *FirecrackerRateLimiter
func (*FirecrackerNetworkInterface) GetStaticConfig ¶
func (m *FirecrackerNetworkInterface) GetStaticConfig() *StaticNetworkConfiguration
func (*FirecrackerNetworkInterface) ProtoMessage ¶
func (*FirecrackerNetworkInterface) ProtoMessage()
func (*FirecrackerNetworkInterface) Reset ¶
func (m *FirecrackerNetworkInterface) Reset()
func (*FirecrackerNetworkInterface) String ¶
func (m *FirecrackerNetworkInterface) String() string
func (*FirecrackerNetworkInterface) XXX_DiscardUnknown ¶
func (m *FirecrackerNetworkInterface) XXX_DiscardUnknown()
func (*FirecrackerNetworkInterface) XXX_Marshal ¶
func (m *FirecrackerNetworkInterface) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*FirecrackerNetworkInterface) XXX_Merge ¶
func (m *FirecrackerNetworkInterface) XXX_Merge(src proto.Message)
func (*FirecrackerNetworkInterface) XXX_Size ¶
func (m *FirecrackerNetworkInterface) XXX_Size() int
func (*FirecrackerNetworkInterface) XXX_Unmarshal ¶
func (m *FirecrackerNetworkInterface) XXX_Unmarshal(b []byte) error
type FirecrackerRateLimiter ¶
type FirecrackerRateLimiter struct {
Bandwidth *FirecrackerTokenBucket `protobuf:"bytes,1,opt,name=Bandwidth,json=bandwidth,proto3" json:"Bandwidth,omitempty"`
Ops *FirecrackerTokenBucket `protobuf:"bytes,2,opt,name=Ops,json=ops,proto3" json:"Ops,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Message to specify an IO rate limiter with bytes/s and ops/s limits
func (*FirecrackerRateLimiter) Descriptor ¶
func (*FirecrackerRateLimiter) Descriptor() ([]byte, []int)
func (*FirecrackerRateLimiter) GetBandwidth ¶
func (m *FirecrackerRateLimiter) GetBandwidth() *FirecrackerTokenBucket
func (*FirecrackerRateLimiter) GetOps ¶
func (m *FirecrackerRateLimiter) GetOps() *FirecrackerTokenBucket
func (*FirecrackerRateLimiter) ProtoMessage ¶
func (*FirecrackerRateLimiter) ProtoMessage()
func (*FirecrackerRateLimiter) Reset ¶
func (m *FirecrackerRateLimiter) Reset()
func (*FirecrackerRateLimiter) String ¶
func (m *FirecrackerRateLimiter) String() string
func (*FirecrackerRateLimiter) XXX_DiscardUnknown ¶
func (m *FirecrackerRateLimiter) XXX_DiscardUnknown()
func (*FirecrackerRateLimiter) XXX_Marshal ¶
func (m *FirecrackerRateLimiter) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*FirecrackerRateLimiter) XXX_Merge ¶
func (m *FirecrackerRateLimiter) XXX_Merge(src proto.Message)
func (*FirecrackerRateLimiter) XXX_Size ¶
func (m *FirecrackerRateLimiter) XXX_Size() int
func (*FirecrackerRateLimiter) XXX_Unmarshal ¶
func (m *FirecrackerRateLimiter) XXX_Unmarshal(b []byte) error
type FirecrackerRootDrive ¶
type FirecrackerRootDrive struct {
// (Required) HostPath is the path on the host to the filesystem image or device
// that will supply the rootfs of the VM.
HostPath string `protobuf:"bytes,1,opt,name=HostPath,json=hostPath,proto3" json:"HostPath,omitempty"`
// (Optional) If the HostPath points to a drive or image with multiple
// partitions, Partuuid specifies which partition will be used to boot
// the VM
Partuuid string `protobuf:"bytes,2,opt,name=Partuuid,json=partuuid,proto3" json:"Partuuid,omitempty"`
// (Optional) If set to true, IsWritable results in the VM Guest's rootfs
// being mounted as read-write. Defaults to false, in which case the
// rootfs is mounted as read-only.
IsWritable bool `protobuf:"varint,3,opt,name=IsWritable,json=isWritable,proto3" json:"IsWritable,omitempty"`
// (Optional) RateLimiter configuration that will be applied to the
// backing-drive for the VM's rootfs
RateLimiter *FirecrackerRateLimiter `protobuf:"bytes,4,opt,name=RateLimiter,json=rateLimiter,proto3" json:"RateLimiter,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Message to specify the block device config for a Firecracker VM
func (*FirecrackerRootDrive) Descriptor ¶
func (*FirecrackerRootDrive) Descriptor() ([]byte, []int)
func (*FirecrackerRootDrive) GetHostPath ¶
func (m *FirecrackerRootDrive) GetHostPath() string
func (*FirecrackerRootDrive) GetIsWritable ¶
func (m *FirecrackerRootDrive) GetIsWritable() bool
func (*FirecrackerRootDrive) GetPartuuid ¶
func (m *FirecrackerRootDrive) GetPartuuid() string
func (*FirecrackerRootDrive) GetRateLimiter ¶
func (m *FirecrackerRootDrive) GetRateLimiter() *FirecrackerRateLimiter
func (*FirecrackerRootDrive) ProtoMessage ¶
func (*FirecrackerRootDrive) ProtoMessage()
func (*FirecrackerRootDrive) Reset ¶
func (m *FirecrackerRootDrive) Reset()
func (*FirecrackerRootDrive) String ¶
func (m *FirecrackerRootDrive) String() string
func (*FirecrackerRootDrive) XXX_DiscardUnknown ¶
func (m *FirecrackerRootDrive) XXX_DiscardUnknown()
func (*FirecrackerRootDrive) XXX_Marshal ¶
func (m *FirecrackerRootDrive) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*FirecrackerRootDrive) XXX_Merge ¶
func (m *FirecrackerRootDrive) XXX_Merge(src proto.Message)
func (*FirecrackerRootDrive) XXX_Size ¶
func (m *FirecrackerRootDrive) XXX_Size() int
func (*FirecrackerRootDrive) XXX_Unmarshal ¶
func (m *FirecrackerRootDrive) XXX_Unmarshal(b []byte) error
type FirecrackerTokenBucket ¶
type FirecrackerTokenBucket struct {
OneTimeBurst int64 `protobuf:"varint,1,opt,name=OneTimeBurst,json=oneTimeBurst,proto3" json:"OneTimeBurst,omitempty"`
RefillTime int64 `protobuf:"varint,2,opt,name=RefillTime,json=refillTime,proto3" json:"RefillTime,omitempty"`
Capacity int64 `protobuf:"varint,3,opt,name=Capacity,json=capacity,proto3" json:"Capacity,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Message to specify a token buicket used to rate limit disk and network IO for a Firecracker VM
func (*FirecrackerTokenBucket) Descriptor ¶
func (*FirecrackerTokenBucket) Descriptor() ([]byte, []int)
func (*FirecrackerTokenBucket) GetCapacity ¶
func (m *FirecrackerTokenBucket) GetCapacity() int64
func (*FirecrackerTokenBucket) GetOneTimeBurst ¶
func (m *FirecrackerTokenBucket) GetOneTimeBurst() int64
func (*FirecrackerTokenBucket) GetRefillTime ¶
func (m *FirecrackerTokenBucket) GetRefillTime() int64
func (*FirecrackerTokenBucket) ProtoMessage ¶
func (*FirecrackerTokenBucket) ProtoMessage()
func (*FirecrackerTokenBucket) Reset ¶
func (m *FirecrackerTokenBucket) Reset()
func (*FirecrackerTokenBucket) String ¶
func (m *FirecrackerTokenBucket) String() string
func (*FirecrackerTokenBucket) XXX_DiscardUnknown ¶
func (m *FirecrackerTokenBucket) XXX_DiscardUnknown()
func (*FirecrackerTokenBucket) XXX_Marshal ¶
func (m *FirecrackerTokenBucket) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*FirecrackerTokenBucket) XXX_Merge ¶
func (m *FirecrackerTokenBucket) XXX_Merge(src proto.Message)
func (*FirecrackerTokenBucket) XXX_Size ¶
func (m *FirecrackerTokenBucket) XXX_Size() int
func (*FirecrackerTokenBucket) XXX_Unmarshal ¶
func (m *FirecrackerTokenBucket) XXX_Unmarshal(b []byte) error
type GetVMInfoRequest ¶
type GetVMInfoRequest struct {
VMID string `protobuf:"bytes,1,opt,name=VMID,json=vMID,proto3" json:"VMID,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetVMInfoRequest) Descriptor ¶
func (*GetVMInfoRequest) Descriptor() ([]byte, []int)
func (*GetVMInfoRequest) GetVMID ¶
func (m *GetVMInfoRequest) GetVMID() string
func (*GetVMInfoRequest) ProtoMessage ¶
func (*GetVMInfoRequest) ProtoMessage()
func (*GetVMInfoRequest) Reset ¶
func (m *GetVMInfoRequest) Reset()
func (*GetVMInfoRequest) String ¶
func (m *GetVMInfoRequest) String() string
func (*GetVMInfoRequest) XXX_DiscardUnknown ¶
func (m *GetVMInfoRequest) XXX_DiscardUnknown()
func (*GetVMInfoRequest) XXX_Marshal ¶
func (m *GetVMInfoRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetVMInfoRequest) XXX_Merge ¶
func (m *GetVMInfoRequest) XXX_Merge(src proto.Message)
func (*GetVMInfoRequest) XXX_Size ¶
func (m *GetVMInfoRequest) XXX_Size() int
func (*GetVMInfoRequest) XXX_Unmarshal ¶
func (m *GetVMInfoRequest) XXX_Unmarshal(b []byte) error
type GetVMInfoResponse ¶
type GetVMInfoResponse struct {
VMID string `protobuf:"bytes,1,opt,name=VMID,json=vMID,proto3" json:"VMID,omitempty"`
SocketPath string `protobuf:"bytes,2,opt,name=SocketPath,json=socketPath,proto3" json:"SocketPath,omitempty"`
LogFifoPath string `protobuf:"bytes,3,opt,name=LogFifoPath,json=logFifoPath,proto3" json:"LogFifoPath,omitempty"`
MetricsFifoPath string `protobuf:"bytes,4,opt,name=MetricsFifoPath,json=metricsFifoPath,proto3" json:"MetricsFifoPath,omitempty"`
CgroupPath string `protobuf:"bytes,5,opt,name=CgroupPath,json=cgroupPath,proto3" json:"CgroupPath,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetVMInfoResponse) Descriptor ¶
func (*GetVMInfoResponse) Descriptor() ([]byte, []int)
func (*GetVMInfoResponse) GetCgroupPath ¶
func (m *GetVMInfoResponse) GetCgroupPath() string
func (*GetVMInfoResponse) GetLogFifoPath ¶
func (m *GetVMInfoResponse) GetLogFifoPath() string
func (*GetVMInfoResponse) GetMetricsFifoPath ¶
func (m *GetVMInfoResponse) GetMetricsFifoPath() string
func (*GetVMInfoResponse) GetSocketPath ¶
func (m *GetVMInfoResponse) GetSocketPath() string
func (*GetVMInfoResponse) GetVMID ¶
func (m *GetVMInfoResponse) GetVMID() string
func (*GetVMInfoResponse) ProtoMessage ¶
func (*GetVMInfoResponse) ProtoMessage()
func (*GetVMInfoResponse) Reset ¶
func (m *GetVMInfoResponse) Reset()
func (*GetVMInfoResponse) String ¶
func (m *GetVMInfoResponse) String() string
func (*GetVMInfoResponse) XXX_DiscardUnknown ¶
func (m *GetVMInfoResponse) XXX_DiscardUnknown()
func (*GetVMInfoResponse) XXX_Marshal ¶
func (m *GetVMInfoResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetVMInfoResponse) XXX_Merge ¶
func (m *GetVMInfoResponse) XXX_Merge(src proto.Message)
func (*GetVMInfoResponse) XXX_Size ¶
func (m *GetVMInfoResponse) XXX_Size() int
func (*GetVMInfoResponse) XXX_Unmarshal ¶
func (m *GetVMInfoResponse) XXX_Unmarshal(b []byte) error
type GetVMMetadataRequest ¶
type GetVMMetadataRequest struct {
VMID string `protobuf:"bytes,1,opt,name=VMID,json=vMID,proto3" json:"VMID,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetVMMetadataRequest) Descriptor ¶
func (*GetVMMetadataRequest) Descriptor() ([]byte, []int)
func (*GetVMMetadataRequest) GetVMID ¶
func (m *GetVMMetadataRequest) GetVMID() string
func (*GetVMMetadataRequest) ProtoMessage ¶
func (*GetVMMetadataRequest) ProtoMessage()
func (*GetVMMetadataRequest) Reset ¶
func (m *GetVMMetadataRequest) Reset()
func (*GetVMMetadataRequest) String ¶
func (m *GetVMMetadataRequest) String() string
func (*GetVMMetadataRequest) XXX_DiscardUnknown ¶
func (m *GetVMMetadataRequest) XXX_DiscardUnknown()
func (*GetVMMetadataRequest) XXX_Marshal ¶
func (m *GetVMMetadataRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetVMMetadataRequest) XXX_Merge ¶
func (m *GetVMMetadataRequest) XXX_Merge(src proto.Message)
func (*GetVMMetadataRequest) XXX_Size ¶
func (m *GetVMMetadataRequest) XXX_Size() int
func (*GetVMMetadataRequest) XXX_Unmarshal ¶
func (m *GetVMMetadataRequest) XXX_Unmarshal(b []byte) error
type GetVMMetadataResponse ¶
type GetVMMetadataResponse struct {
Metadata string `protobuf:"bytes,1,opt,name=Metadata,json=metadata,proto3" json:"Metadata,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetVMMetadataResponse) Descriptor ¶
func (*GetVMMetadataResponse) Descriptor() ([]byte, []int)
func (*GetVMMetadataResponse) GetMetadata ¶
func (m *GetVMMetadataResponse) GetMetadata() string
func (*GetVMMetadataResponse) ProtoMessage ¶
func (*GetVMMetadataResponse) ProtoMessage()
func (*GetVMMetadataResponse) Reset ¶
func (m *GetVMMetadataResponse) Reset()
func (*GetVMMetadataResponse) String ¶
func (m *GetVMMetadataResponse) String() string
func (*GetVMMetadataResponse) XXX_DiscardUnknown ¶
func (m *GetVMMetadataResponse) XXX_DiscardUnknown()
func (*GetVMMetadataResponse) XXX_Marshal ¶
func (m *GetVMMetadataResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetVMMetadataResponse) XXX_Merge ¶
func (m *GetVMMetadataResponse) XXX_Merge(src proto.Message)
func (*GetVMMetadataResponse) XXX_Size ¶
func (m *GetVMMetadataResponse) XXX_Size() int
func (*GetVMMetadataResponse) XXX_Unmarshal ¶
func (m *GetVMMetadataResponse) XXX_Unmarshal(b []byte) error
type IPConfiguration ¶
type IPConfiguration struct {
// PrimaryAddr specifies, in CIDR notation, the primary address
// and subnet that a network interface will be assigned inside
// the VM.
PrimaryAddr string `protobuf:"bytes,1,opt,name=PrimaryAddr,json=primaryAddr,proto3" json:"PrimaryAddr,omitempty"`
// GatewayAddr specifies the default gateway that a network interface
// should use inside the VM.
GatewayAddr string `protobuf:"bytes,3,opt,name=GatewayAddr,json=gatewayAddr,proto3" json:"GatewayAddr,omitempty"`
// Nameservers is a list of nameservers that the VM will be configured
// to use internally. Currently only up to 2 nameservers can be specified
// (any more in the list will be ignored) and configuration is provided
// to the VM via /proc/net/pnp.
Nameservers []string `protobuf:"bytes,4,rep,name=Nameservers,json=nameservers,proto3" json:"Nameservers,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Message to specify static IP configuration that will be applied to a Firecracker VM's network interface internally
func (*IPConfiguration) Descriptor ¶
func (*IPConfiguration) Descriptor() ([]byte, []int)
func (*IPConfiguration) GetGatewayAddr ¶
func (m *IPConfiguration) GetGatewayAddr() string
func (*IPConfiguration) GetNameservers ¶
func (m *IPConfiguration) GetNameservers() []string
func (*IPConfiguration) GetPrimaryAddr ¶
func (m *IPConfiguration) GetPrimaryAddr() string
func (*IPConfiguration) ProtoMessage ¶
func (*IPConfiguration) ProtoMessage()
func (*IPConfiguration) Reset ¶
func (m *IPConfiguration) Reset()
func (*IPConfiguration) String ¶
func (m *IPConfiguration) String() string
func (*IPConfiguration) XXX_DiscardUnknown ¶
func (m *IPConfiguration) XXX_DiscardUnknown()
func (*IPConfiguration) XXX_Marshal ¶
func (m *IPConfiguration) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*IPConfiguration) XXX_Merge ¶
func (m *IPConfiguration) XXX_Merge(src proto.Message)
func (*IPConfiguration) XXX_Size ¶
func (m *IPConfiguration) XXX_Size() int
func (*IPConfiguration) XXX_Unmarshal ¶
func (m *IPConfiguration) XXX_Unmarshal(b []byte) error
type JailerConfig ¶
type JailerConfig struct {
NetNS string `protobuf:"bytes,1,opt,name=NetNS,json=netNS,proto3" json:"NetNS,omitempty"`
// List of the physical numbers of the CPUs on which processes in that
// cpuset are allowed to execute. See List Format below for a description
// of the format of cpus.
//
// The CPUs allowed to a cpuset may be changed by writing a new list to its
// cpus file.
// Taken from http://man7.org/linux/man-pages/man7/cpuset.7.html
//
// This is formatted as specified in the cpuset man page under "List Format"
// http://man7.org/linux/man-pages/man7/cpuset.7.html
CPUs string `protobuf:"bytes,2,opt,name=CPUs,json=cPUs,proto3" json:"CPUs,omitempty"`
// List of memory nodes on which processes in this cpuset are allowed to
// allocate memory. See List Format below for a description of the format
// of mems.
// Taken from http://man7.org/linux/man-pages/man7/cpuset.7.html
//
// This is formatted as specified in the cpuset man page under "List Format"
// http://man7.org/linux/man-pages/man7/cpuset.7.html
Mems string `protobuf:"bytes,3,opt,name=Mems,json=mems,proto3" json:"Mems,omitempty"`
UID uint32 `protobuf:"varint,4,opt,name=UID,json=uID,proto3" json:"UID,omitempty"`
GID uint32 `protobuf:"varint,5,opt,name=GID,json=gID,proto3" json:"GID,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*JailerConfig) Descriptor ¶
func (*JailerConfig) Descriptor() ([]byte, []int)
func (*JailerConfig) GetCPUs ¶
func (m *JailerConfig) GetCPUs() string
func (*JailerConfig) GetGID ¶
func (m *JailerConfig) GetGID() uint32
func (*JailerConfig) GetMems ¶
func (m *JailerConfig) GetMems() string
func (*JailerConfig) GetNetNS ¶
func (m *JailerConfig) GetNetNS() string
func (*JailerConfig) GetUID ¶
func (m *JailerConfig) GetUID() uint32
func (*JailerConfig) ProtoMessage ¶
func (*JailerConfig) ProtoMessage()
func (*JailerConfig) Reset ¶
func (m *JailerConfig) Reset()
func (*JailerConfig) String ¶
func (m *JailerConfig) String() string
func (*JailerConfig) XXX_DiscardUnknown ¶
func (m *JailerConfig) XXX_DiscardUnknown()
func (*JailerConfig) XXX_Marshal ¶
func (m *JailerConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*JailerConfig) XXX_Merge ¶
func (m *JailerConfig) XXX_Merge(src proto.Message)
func (*JailerConfig) XXX_Size ¶
func (m *JailerConfig) XXX_Size() int
func (*JailerConfig) XXX_Unmarshal ¶
func (m *JailerConfig) XXX_Unmarshal(b []byte) error
type SetVMMetadataRequest ¶
type SetVMMetadataRequest struct {
VMID string `protobuf:"bytes,1,opt,name=VMID,json=vMID,proto3" json:"VMID,omitempty"`
Metadata string `protobuf:"bytes,2,opt,name=Metadata,json=metadata,proto3" json:"Metadata,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*SetVMMetadataRequest) Descriptor ¶
func (*SetVMMetadataRequest) Descriptor() ([]byte, []int)
func (*SetVMMetadataRequest) GetMetadata ¶
func (m *SetVMMetadataRequest) GetMetadata() string
func (*SetVMMetadataRequest) GetVMID ¶
func (m *SetVMMetadataRequest) GetVMID() string
func (*SetVMMetadataRequest) ProtoMessage ¶
func (*SetVMMetadataRequest) ProtoMessage()
func (*SetVMMetadataRequest) Reset ¶
func (m *SetVMMetadataRequest) Reset()
func (*SetVMMetadataRequest) String ¶
func (m *SetVMMetadataRequest) String() string
func (*SetVMMetadataRequest) XXX_DiscardUnknown ¶
func (m *SetVMMetadataRequest) XXX_DiscardUnknown()
func (*SetVMMetadataRequest) XXX_Marshal ¶
func (m *SetVMMetadataRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*SetVMMetadataRequest) XXX_Merge ¶
func (m *SetVMMetadataRequest) XXX_Merge(src proto.Message)
func (*SetVMMetadataRequest) XXX_Size ¶
func (m *SetVMMetadataRequest) XXX_Size() int
func (*SetVMMetadataRequest) XXX_Unmarshal ¶
func (m *SetVMMetadataRequest) XXX_Unmarshal(b []byte) error
type StaticNetworkConfiguration ¶
type StaticNetworkConfiguration struct {
MacAddress string `protobuf:"bytes,1,opt,name=MacAddress,json=macAddress,proto3" json:"MacAddress,omitempty"`
HostDevName string `protobuf:"bytes,2,opt,name=HostDevName,json=hostDevName,proto3" json:"HostDevName,omitempty"`
// IPConfig optionally provides static IP configuration that will be configured
// on the VM's internal networking interface. If not specified, no IP
// configuration will be applied to the VM's internal nic automatically.
IPConfig *IPConfiguration `protobuf:"bytes,3,opt,name=IPConfig,json=iPConfig,proto3" json:"IPConfig,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Message to specify static configuration parameters for a Firecracker VM's network interface
func (*StaticNetworkConfiguration) Descriptor ¶
func (*StaticNetworkConfiguration) Descriptor() ([]byte, []int)
func (*StaticNetworkConfiguration) GetHostDevName ¶
func (m *StaticNetworkConfiguration) GetHostDevName() string
func (*StaticNetworkConfiguration) GetIPConfig ¶
func (m *StaticNetworkConfiguration) GetIPConfig() *IPConfiguration
func (*StaticNetworkConfiguration) GetMacAddress ¶
func (m *StaticNetworkConfiguration) GetMacAddress() string
func (*StaticNetworkConfiguration) ProtoMessage ¶
func (*StaticNetworkConfiguration) ProtoMessage()
func (*StaticNetworkConfiguration) Reset ¶
func (m *StaticNetworkConfiguration) Reset()
func (*StaticNetworkConfiguration) String ¶
func (m *StaticNetworkConfiguration) String() string
func (*StaticNetworkConfiguration) XXX_DiscardUnknown ¶
func (m *StaticNetworkConfiguration) XXX_DiscardUnknown()
func (*StaticNetworkConfiguration) XXX_Marshal ¶
func (m *StaticNetworkConfiguration) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*StaticNetworkConfiguration) XXX_Merge ¶
func (m *StaticNetworkConfiguration) XXX_Merge(src proto.Message)
func (*StaticNetworkConfiguration) XXX_Size ¶
func (m *StaticNetworkConfiguration) XXX_Size() int
func (*StaticNetworkConfiguration) XXX_Unmarshal ¶
func (m *StaticNetworkConfiguration) XXX_Unmarshal(b []byte) error
type StopVMRequest ¶
type StopVMRequest struct {
VMID string `protobuf:"bytes,1,opt,name=VMID,json=vMID,proto3" json:"VMID,omitempty"`
TimeoutSeconds uint32 `protobuf:"varint,2,opt,name=TimeoutSeconds,json=timeoutSeconds,proto3" json:"TimeoutSeconds,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*StopVMRequest) Descriptor ¶
func (*StopVMRequest) Descriptor() ([]byte, []int)
func (*StopVMRequest) GetTimeoutSeconds ¶
func (m *StopVMRequest) GetTimeoutSeconds() uint32
func (*StopVMRequest) GetVMID ¶
func (m *StopVMRequest) GetVMID() string
func (*StopVMRequest) ProtoMessage ¶
func (*StopVMRequest) ProtoMessage()
func (*StopVMRequest) Reset ¶
func (m *StopVMRequest) Reset()
func (*StopVMRequest) String ¶
func (m *StopVMRequest) String() string
func (*StopVMRequest) XXX_DiscardUnknown ¶
func (m *StopVMRequest) XXX_DiscardUnknown()
func (*StopVMRequest) XXX_Marshal ¶
func (m *StopVMRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*StopVMRequest) XXX_Merge ¶
func (m *StopVMRequest) XXX_Merge(src proto.Message)
func (*StopVMRequest) XXX_Size ¶
func (m *StopVMRequest) XXX_Size() int
func (*StopVMRequest) XXX_Unmarshal ¶
func (m *StopVMRequest) XXX_Unmarshal(b []byte) error
type UpdateVMMetadataRequest ¶
type UpdateVMMetadataRequest struct {
VMID string `protobuf:"bytes,1,opt,name=VMID,json=vMID,proto3" json:"VMID,omitempty"`
Metadata string `protobuf:"bytes,2,opt,name=Metadata,json=metadata,proto3" json:"Metadata,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*UpdateVMMetadataRequest) Descriptor ¶
func (*UpdateVMMetadataRequest) Descriptor() ([]byte, []int)
func (*UpdateVMMetadataRequest) GetMetadata ¶
func (m *UpdateVMMetadataRequest) GetMetadata() string
func (*UpdateVMMetadataRequest) GetVMID ¶
func (m *UpdateVMMetadataRequest) GetVMID() string
func (*UpdateVMMetadataRequest) ProtoMessage ¶
func (*UpdateVMMetadataRequest) ProtoMessage()
func (*UpdateVMMetadataRequest) Reset ¶
func (m *UpdateVMMetadataRequest) Reset()
func (*UpdateVMMetadataRequest) String ¶
func (m *UpdateVMMetadataRequest) String() string
func (*UpdateVMMetadataRequest) XXX_DiscardUnknown ¶
func (m *UpdateVMMetadataRequest) XXX_DiscardUnknown()
func (*UpdateVMMetadataRequest) XXX_Marshal ¶
func (m *UpdateVMMetadataRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*UpdateVMMetadataRequest) XXX_Merge ¶
func (m *UpdateVMMetadataRequest) XXX_Merge(src proto.Message)
func (*UpdateVMMetadataRequest) XXX_Size ¶
func (m *UpdateVMMetadataRequest) XXX_Size() int
func (*UpdateVMMetadataRequest) XXX_Unmarshal ¶
func (m *UpdateVMMetadataRequest) XXX_Unmarshal(b []byte) error
type VMStart ¶
type VMStart struct {
VMID string `protobuf:"bytes,1,opt,name=VMID,json=vMID,proto3" json:"VMID,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*VMStart) Descriptor ¶
func (*VMStart) ProtoMessage ¶
func (*VMStart) ProtoMessage()
func (*VMStart) XXX_DiscardUnknown ¶
func (m *VMStart) XXX_DiscardUnknown()
func (*VMStart) XXX_Marshal ¶
func (*VMStart) XXX_Unmarshal ¶
type VMStop ¶
type VMStop struct {
VMID string `protobuf:"bytes,1,opt,name=VMID,json=vMID,proto3" json:"VMID,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*VMStop) Descriptor ¶
func (*VMStop) ProtoMessage ¶
func (*VMStop) ProtoMessage()
func (*VMStop) XXX_DiscardUnknown ¶
func (m *VMStop) XXX_DiscardUnknown()